package controllers

import (
	"github.com/rdlucklib/rdluck_tools/paging"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/services"
	"hongze/hongze_cygx/utils"
)

type ChartController struct {
	BaseAuthController
}

type BaseChartController struct {
	BaseCommonController
}

// @Title 图表标签分类
// @Description 图表标签分类接口
// @Success 200 {object} models.ChartPtagResp
// @router /patg [get]
func (this *BaseChartController) Patg() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	list, err := services.GetChartPtagByApi()
	if err != nil {
		br.Msg = "获取图表分类失败！"
		br.ErrMsg = "获取图表分类失败"
		return
	}
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = list
}

// @Title 我的收藏
// @Description 我的收藏接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Success 200 {object} models.HomeChartListItem
// @router /my/collection [get]
func (this *ChartController) Collection() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	mobile := user.Mobile
	if mobile == "" {
		br.Msg = "请绑定手机号！"
		return
	}
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	list, err := services.GetChartCollectionByApi(mobile)
	if err != nil {
		br.Msg = "获取图表分类失败！"
		br.ErrMsg = "获取图表分类失败"
		return
	}
	page := paging.GetPaging(currentIndex, pageSize, len(list))
	resp := new(models.HomeChartListItem)
	resp.List = list
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}
